@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Time::Seconds;
 
-our $VERSION = "0.06";
+our $VERSION = "0.07";
 
 use constant { border => 1000000 };
 
@@ -122,7 +122,6 @@ __END__
 Business::Tax::Withholding::JP - auto calculation for Japanese tax and withholding
 
 Business::Tax::Withholding::JP - 日本の消費税と源泉徴収のややこしい計算を自動化します。
-
  
 =head1 SYNOPSIS
 
@@ -137,13 +136,13 @@ Business::Tax::Withholding::JP - 日本の消費税と源泉徴収のややこ
  $calc->withholding();  # 1021
  $calc->total();        # 9779
 
- # Or you can set the date in period of special tax being expired
+ # Or you can set the date in period of special tax will expire
  $calc = Business::Tax::Withholding::JP->new( date => '2038-01-01' );
  $calc->price(10000);
  $calc->withholding();  # 1000
  $calc->total();        # 9800
 
- # And you may ignore the withholings
+ # And you may ignore the withholdings
  $calc = Business::Tax::Withholding::JP->new( no_wh => 1 );
  $calc->price(10000);   # 10000
  $calc->amount(2);      # 2
@@ -152,6 +151,15 @@ Business::Tax::Withholding::JP - 日本の消費税と源泉徴収のややこ
  $calc->withholding();  # 0
  $calc->total();        # 21600
 
+ # After 2019/10/01, this module will calculate with 10% consumption tax
+ $calc = Business::Tax::Withholding::JP->new( price => 10000 );
+ $calc->net();          # 10000
+ $calc->amount(2);      # 2
+ $calc->subtotal();     # 20000
+ $calc->tax();          # 2000
+ $calc->withholding();  # 2042
+ $calc->total();        # 19958
+
 =head1 DESCRIPTION
 
 Business::Tax::Withholding::JP
@@ -160,7 +168,7 @@ is useful calculator for long term in Japanese Business.
 You can get correctly taxes and withholdings from price in your context
 without worrying about the special tax for reconstructing from the Earthquake.
 
-the consumption tax B<rate is 8%>
+the consumption tax B<rate is 8% (automatically up to 10% after 2019/10/01)>
  
 You can also ignore the withholings. It means this module can be a tax calculator
 
@@ -192,9 +200,9 @@ the amount of your products will be set. defaults 1.
 
 =item date
 
-You can set payday. the net of withholding depends on this. default is today.
+You can set payday. the net of tax and withholding depends on this. default is today.
  
-支払日を指定してください。源泉徴収額が変動することがあります。指定しなければ今日として計算します。
+支払日を指定してください。消費税額と源泉徴収額が変動します。指定しなければ今日として計算します。
  
 =item no_wh
  
@@ -274,6 +282,6 @@ it under the same terms as Perl itself.
 
 =head1 AUTHOR
 
-Yuki YoshidaE<lt>worthmine@gmail.comE<gt>
+Yuki Yoshida E<lt>worthmine@gmail.comE<gt>
 
 =cut
